Cheshire3 Object Model - ResultSet
==================================

.. _objects-resultSet-api:

API
---

.. autoclass:: cheshire3.baseObjects.ResultSet
   :members:


.. _objects-resultSet-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.resultSet.SimpleResultSet

.. autoclass:: cheshire3.resultSet.SimpleResultSetItem

[a :py:class:`~cheshire3.resultSet.SimpleResultSet` consists of zero or more
:py:class:`~cheshire3.resultSet.SimpleResultSetItem`\ s]
